
# **Videomass** provides a graphical interface for audio and video conversions through FFmpeg.

Now also compatible with Python3 and wxPython-Phoenix.    

* [View progect on PyPi](https://pypi.org/project/videomass/)
* [GitHub Page](https://github.com/jeanslack/Videomass)
* [Support Page and Documentation](http://jeanslack.github.io/Videomass)
* [Wiki page](https://github.com/jeanslack/Videomass/wiki)
* [Downloads Source Code](https://github.com/jeanslack/Videomass/releases)
* [Installers for Windows and MacOsX](https://sourceforge.net/projects/videomass2/)

## Features

- Drag n' Drop interface
- Presets manager interface with fully customizable and expandable profiles  
- Displaying metadata streams information 
- Preview of exported media
- Preview video filters
- Reproduction of imported media
- Video conversions interface 
- Audio conversions interface
- Save jpg images from a video sequence
- Audio peak level analysis with normalization process   
- Grabbing audio streams from video with multilingual selection  
- Selection of the time interval (for exports, previews, reproduction, tests)
- Convert multiple files at once 
- Log management
- Multi language (English and Italian Languages support for now)
- Work on many platforms where Python and wxPython are supported, 
  including Linux, Unix, MacOs and Windows.
- Compatible with Python 2 and 3

## Essential Dependencies

**Required:**
- Python (2/3)     
- wxPython  (Classic/Phoenix)  

**Optionals:**
- ffmpeg >= 3.2
- ffprobe (for multimedia streams analysis) (can be built-in into ffmpeg)
- ffplay (media player for media preview) (can be built-in into ffmpeg)

